// SIDXC.h
//
// Copyright (c) 1999 - 2004 Bruxton Corporation
//
// Author: Lin Ci
//
// SIDX main module that defines SIDX exported functions for C.

#ifndef SIDXC_H
#define SIDXC_H

#ifndef int64_t
#define int64_t __int64
#endif

#ifdef __cplusplus
extern "C"
{
#endif

int WINAPI SIDXOpen(void** sidx, void* frame_window);

void WINAPI SIDXClose(void* sidx);

int WINAPI SIDXGetSerialNumber(void* _sidx, int* serial_number);

int WINAPI SIDXSettingsOpenCamera(void* _sidx, const wchar_t* _settings, void** _camera);

int WINAPI SIDXCameraOpen(void* _sidx, const wchar_t* _camera_id, void** _camera);

void WINAPI SIDXGetStatusText(void* _sidx, int error, wchar_t* message, int length);

int WINAPI SIDXDialogCameraSelector(void* _sidx, int* canceled, void** _camera);

int WINAPI SIDXGetCameraCount(void* _sidx, int* count);

int WINAPI SIDXGetCameraName
	(void* _sidx, int index, wchar_t* _camera_id, int length);

void WINAPI SIDXCameraClose(void* _camera);

int WINAPI SIDXSettingsGet
	(void* _camera, wchar_t* settings, int length);

bool WINAPI SIDXCameraIsVendor(void* _camera, int vendor);

int WINAPI SIDXCameraGetName(void* _camera, wchar_t* _name, int length);
void WINAPI SIDXCameraGetStatusText
	(void* _camera, int error, wchar_t* message, int length);
int WINAPI SIDXCameraGetDescription
	(void* _camera, wchar_t* description, int length);

int WINAPI SIDXDialogCamera(void* _camera, int* canceled);
int WINAPI SIDXDialogImage(void* _camera, int* canceled);

int WINAPI SIDXBinningSet(void* _camera, int binning_x, int binning_y);
int WINAPI SIDXROIClear(void* _camera);
int WINAPI SIDXROISet(void* _camera, int x1, int y1, int x2, int y2);
int WINAPI SIDXRotateReset(void* _camera);
int WINAPI SIDXRotateSet(void* _camera, int rotate_count);
int WINAPI SIDXRotateMirrorX(void* _camera);
int WINAPI SIDXRotateMirrorY(void* _camera);
int WINAPI SIDXShutterSet(void* _camera, int mode);
int WINAPI SIDXTemperaturePowerOffCooling(void* _camera);
int WINAPI SIDXTemperaturePowerOnCooling(void* _camera);
int WINAPI SIDXAcquisitionBeginContinuous(void* _camera);
int WINAPI SIDXAcquisitionBeginFocus(void* _camera);
int WINAPI SIDXAcquisitionBeginSequence(void* _camera, int frames);
int WINAPI SIDXAcquisitionBeginScripting(void* _camera, const wchar_t* script);
void WINAPI SIDXAcquisitionEnd(void* _camera);
int WINAPI SIDXAcquisitionStart(void* _camera);
void WINAPI SIDXAcquisitionStop(void* _camera);
void WINAPI SIDXAcquisitionAbort(void* _camera);
int WINAPI SIDXCameraGetFrameRate(void* _camera, double* rate);

int WINAPI SIDXServiceIntervalGet(void* _camera, double* _interval);
int WINAPI SIDXServiceIntervalSet(void* _camera, double _interval);

int WINAPI SIDXSettingSet(void* _camera, const wchar_t* _tag, const wchar_t* value);

int WINAPI SIDXSettingGet
	(void* _camera, const wchar_t* tag, wchar_t* value, int length);

int WINAPI SIDXTemperatureGet(void* _camera, double* temperature, int* locked, int* hardware_provided);

int WINAPI SIDXTemperatureSetSetpoint(void* _camera, double setpoint);

int WINAPI SIDXTemperatureGetSetpoint(void* _camera, double* setpoint, double* minimum, double* maximum, int* range_valid);

int WINAPI SIDXShutterGet(void* _camera, int* mode);

int WINAPI SIDXShutterModeAvailable(void* _camera, int mode, int* available);

int WINAPI SIDXSensorGetParameters(void* _camera, int* x, int* y, int* pixel_depth);

int WINAPI SIDXBinningXAvailable(void* _camera, int binning_x, int* valid);

int WINAPI SIDXBinningYAvailable(void* _camera, int binning_y, int* valid);

int WINAPI SIDXBinningSet(void* _camera, int binning_x, int binning_y);


int WINAPI SIDXGainGetCount(void* _camera, int* count);

int WINAPI SIDXGainGet(void* _camera, int index, wchar_t* _gain, int length);

int WINAPI SIDXGainSet(void* _camera, int index);

int WINAPI SIDXGainGetCurrent(void* _camera, int* gain);

int WINAPI SIDXModeGet(void* _camera, int index, wchar_t* description, int length);

int WINAPI SIDXModeGetCount(void* _camera, int* count);

int WINAPI SIDXModeGetCurrent(void* _camera, int* current);

int WINAPI SIDXModeSet(void* _camera, int index);

int WINAPI SIDXExposureTimeGetRange(void* _camera, double* minimum, double* maximum, double* resolution);

int WINAPI SIDXExposureTimeSet(void* _camera, double exposure);

int WINAPI SIDXExposureTimeGet(void* _camera, double* exposure);

int WINAPI SIDXTriggerSet(void* _camera, int mode);
int WINAPI SIDXTriggerGet(void* _camera, int* mode);

int WINAPI SIDXTriggerModeAvailable(void* _camera, int mode, int* available);


int WINAPI SIDXAcquisitionGetSize
	(void* _camera, int roi_index, int* bytes, int* pixels_x, int* pixels_y);

int WINAPI SIDXAcquisitionGetFrames
	(void* _camera, int frames, int roi, void* image, unsigned int* time, int* frames_returned);

int WINAPI SIDXAcquisitionFramesAvailable(void* _camera, int* frames_available);

int WINAPI SIDXCameraServiceGet
	(void* _camera, wchar_t*  information, int length);

int WINAPI SIDXCameraGetTimeToGetReady(void* _camera, DWORD* _time);

int WINAPI SIDXCameraGetTimeToGetFirstImage(void* _camera, DWORD* _time);

int WINAPI SIDXCameraGetFrameRate(void* _camera, double* rate);

int WINAPI SIDXGetProperties(void* _sidx, int* serial_number);

int WINAPI SIDXSettingsRestoreCamera(void* _sidx, void** _camera);
int WINAPI SIDXSettingsSaveCamera(void* _camera);

int WINAPI SIDXTestSet(void* _sidx, int index, int value);

#ifdef __cplusplus
}
#endif

#endif